MCPcopy Create free account
hub / github.com/arrayfire/arrayfire / locate_features

Function locate_features

src/backend/cuda/kernel/fast.hpp:194–212  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

192
193template<typename T, int arc_length>
194__global__ void locate_features(CParam<T> in, float *score, const float thr,
195 const unsigned edge,
196 cudaTextureObject_t luTable) {
197 unsigned ix = threadIdx.x;
198 unsigned iy = threadIdx.y;
199 unsigned bx = blockDim.x;
200 unsigned by = blockDim.y;
201 unsigned x = bx * blockIdx.x + ix + edge;
202 unsigned y = by * blockIdx.y + iy + edge;
203 unsigned lx = bx / 2 + 3;
204 unsigned ly = by / 2 + 3;
205
206 SharedMemory<T> shared;
207 T *local_image_curr = shared.getPointer();
208 load_shared_image(in, local_image_curr, ix, iy, bx, by, x, y, lx, ly, edge);
209 __syncthreads();
210 locate_features_core<T, arc_length>(local_image_curr, score, in.dims[0],
211 in.dims[1], thr, x, y, edge, luTable);
212}
213
214template<bool nonmax>
215__global__ void non_max_counts(unsigned *d_counts, unsigned *d_offsets,

Callers

nothing calls this directly

Calls 2

load_shared_imageFunction · 0.85
getPointerMethod · 0.80

Tested by

no test coverage detected